% 0.5 - Added FullPageImage functionality
% 0.6 - Reduce the redudancy from abstracthead command
\ProvidesClass{mito}[2019/01/04 version 0.6 DOSZ MITO - Issue]
\NeedsTeXFormat{LaTeX2e}


\DeclareOption*{\InputIfFileExists{\CurrentOption.min}{}{
\PassOptionsToClass{\CurrentOption}{article}}}

\ProcessOptions \relax

\usepackage{etoolbox}

\newcounter{abstractAuthorCounter}
\newcounter{colnum}

\newcommand{\newabstract}[0]{\setcounter{abstractAuthorCounter}{0} \arabic{abstractAuthorCounter}}
\newcommand{\addauthor}[2]{\csdef{abstractActualAuthors\arabic{abstractAuthorCounter}}{#1} \stepcounter{abstractAuthorCounter}}



\newcommand{\abstracthead}[2]{\pagebreak\begin{center}{\renewcommand{\inst}{}\section[#1: #2]{#2}} \textbf{#1}\\[.0 cm]\end{center}}

\newcommand{\abstractheadTocSpecTitle}[3]{\pagebreak\begin{center}{\renewcommand{\inst}{}\section[#1: #2]{#3}} \textbf{#1}\\[.0 cm]\end{center}}


\newcommand{\abstractinstitute}[1]{\begin{center}\textbf{#1}\\[.3 cm]\end{center}}
\newcommand{\abstractbody}[1]{\begin{justify} #1\\[.1 cm] \end{justify}}

\newcommand{\surname}[1]{\textbf{\MakeUppercase{#1}}}
\newcommand{\forename}[1]{#1}

\newcommand{\lecturer}[2]{\begin{minipage}[t]{.3\linewidth}
  \strut\vspace*{-\baselineskip}\newline\includegraphics[width=\linewidth]{#1}
\end{minipage}
\hspace{0.02\linewidth}
\begin{minipage}[t]{.6\linewidth}
  #2
\end{minipage}\\[2cm]}

\newcommand{\abstractcite}[1]{[#1]}



\newcommand{\reference}[2]{
    \begin{minipage}[t]{0.05\textwidth}
        \begin{flushleft}
        [#1]
        \end{flushleft}
    \end{minipage}
    \begin{minipage}[t]{0.95\textwidth}
        \begin{flushleft}
        #2
        \end{flushleft}
    \end{minipage}
    
}

\newcommand{\acknowledgment}[1]{
    \vfill
    #1
}
\newcommand{\acknowledgmentwithimage}[2]{
    \vfill
    \begin{minipage}{0.2\textwidth}
        \begin{center}
            \includegraphics[width=0.8\textwidth]{#1}
        \end{center}
    \end{minipage}
    \begin{minipage}{0.8\textwidth}
        \begin{flushleft}
        #2
        \end{flushleft}
    \end{minipage}
}

\newcommand{\timeslotcell}[2]{
\renewcommand{\arraystretch}{1}
\begin{tabular}[t]{@{}ll} #1 & \\ \textit{#2} & \\ \end{tabular}
}
\newcommand{\lecturetimeslotcell}[3]{
\renewcommand{\arraystretch}{1}
\begin{tabular}[t]{@{}ll} #1 & \\ \textbf{#2} & \\ \textit{#3} & \\ \end{tabular}
}


\def\inst#1{\unskip$^{#1}$}

\LoadClass{article}

\usepackage[a5paper, margin=2cm]{geometry}
\usepackage[english]{babel}
\usepackage{natbib}
\usepackage{url}
\usepackage[utf8x]{inputenc}
\usepackage{amsmath}
\usepackage{graphicx}
\graphicspath{{images/}}
\usepackage{parskip}
\usepackage{fancyhdr}
\usepackage{ragged2e}
\usepackage{makecell}
\usepackage{amssymb}
\usepackage{amsthm}



%fullpageImg
\usepackage{eso-pic}
\newcommand\FullPageImage[1]{%
    \newpage
    \AddToShipoutPicture*{
        \put(0,0){%
            \parbox[b][\paperheight]{\paperwidth}{%
                \vfill
                \begin{center}
                \includegraphics[width=\paperwidth,height=\paperheight,keepaspectratio]{#1}%
                \end{center}
                \vfill
            }
        }
    }
    \thispagestyle{empty}
    \vspace*{4cm}
    \newpage
}
\newcommand\emptypage[1]{%
    \newpage
    \thispagestyle{empty}
    \vspace*{4cm}
    \newpage
}

\linespread{1.2}
 
\title{WSPS8}								
\author{DOSZ MITO}								
\date{28th-30th January, 2022}										


\makeatletter
\let\thetitle\@title
\let\theauthor\@author
\let\thedate\@date
\makeatother

\pagestyle{fancy}
\fancyhf{}
\lhead{DOSZ MITO}
\rhead{WSPS 8}
\cfoot{\thepage}

%% remove numbering from sections
\makeatletter
\renewcommand{\@seccntformat}[1]{}
\makeatother

%% Remove numberinf from ToC
\makeatletter
\let\latexl@section\l@section
\def\l@section#1#2{\begingroup\let\numberline\@gobble\latexl@section{#1}{#2}\endgroup}
\makeatother

\makeatletter
\renewcommand*{\numberline}[1]{%
  \hb@xt@\@tempdima{\hfil#1 }%
}
\makeatother

%center the stuff
\usepackage{titlesec}
\titleformat{\section}[block]{\Large\bfseries\filcenter}{}{1em}{}

